@@ -104,6 +104,26 @@ def calibrate_settings(integration_test_data: Path) -> Path:
     return out
 
 
+@pytest.fixture(scope="session")
+def calibrate_settings2(integration_test_data: Path) -> Path:
+    settings = {
+        "calfile": str(integration_test_data / "calfile_Rcv_2017_05.h5"),
+        "s11_path": str(
+            integration_test_data / "S11_blade_low_band_2015_342_03_14.txt.csv"
+        ),
+        "balun_correction": True,
+        "antenna_correction": False,
+        "ground_correction": ":",
+        "beam_file": "",
+    }
+
+    out = integration_test_data / "calibrate1.yaml"
+    with open(out, "w") as fl:
+        yaml.dump(settings, fl)
+
+    return out
+
+
 @pytest.fixture(scope="session")
 def raw_step(
     integration_test_data: Path,
@@ -162,6 +182,31 @@ def cal_step(
     )
 
 
+@pytest.fixture(scope="session")
+def cal_step2(
+    raw_step: Tuple[RawData, RawData],
+    calibrate_settings2: Path,
+    edges_config: dict,
+    settings: Path,
+) -> Tuple[CalibratedData, CalibratedData]:
+    invoke(
+        cli.process,
+        [
+            "calibrate",
+            str(calibrate_settings2),
+            "-i",
+            str(raw_step[0].filename.parent / "*.h5"),
+            "-l",
+            "calibrated2",
+        ],
+    )
+
+    return tuple(
+        read_step(fl)
+        for fl in sorted((raw_step[0].filename.parent / "calibrated2").glob("*.h5"))
+    )
+
+
 @pytest.fixture(scope="session")
 def model_step(cal_step, settings: Path, integration_test_data: Path):
     with open(settings / "model.yml") as fl:
